==> qtmobilehotspot_0.3.1.tar.gz: qtmobilehotspot-0.3.1/qtmhMacFilter/libqtmhmacfilter-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>MacInputDialogClass</name>
    <message>
        <location filename="src/macinputdialog.ui" line="14"/>
        <source>Add a new MAC...</source>
        <translation>Ajouter une nouvelle MAC...</translation>
    </message>
    <message>
        <location filename="src/macinputdialog.ui" line="24"/>
        <source>Machine name :</source>
        <translation>Nom de machine</translation>
    </message>
    <message>
        <location filename="src/macinputdialog.ui" line="34"/>
        <source>MAC address :</source>
        <translation>Adresse MAC</translation>
    </message>
</context>
<context>
    <name>MobileHotspotConfiguration</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="32"/>
        <source>MAC Filter</source>
        <translation>Filtrage MAC</translation>
    </message>
</context>
<context>
    <name>PluginGUI</name>
    <message>
        <location filename="src/plugingui.cpp" line="54"/>
        <source>Allow those MACs</source>
        <translation>Autoriser</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="55"/>
        <source>Deny those MACs</source>
        <translation>Interdire</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="56"/>
        <source>No filtering</source>
        <translation>Pas de filtrage</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="103"/>
        <source>Empty name</source>
        <translation>Nom vide</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="106"/>
        <source>A MAC address comes in 6 parts separated by colons (:)</source>
        <oldsource>A MAC address comes in 6 parts separated by semicolons</oldsource>
        <translation>Une adresse MAC est formée de 6 parties séparées par des double points</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="110"/>
        <source>A part of a MAC has a length of 2</source>
        <translation>Une partie de MAC a une longueur de 2</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="114"/>
        <source>Digits in a MAC go from 0 to f</source>
        <translation>Les caractères formant une MAC vont de 0 à f</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="120"/>
        <source>Invalid MAC</source>
        <translation>MAC invalide</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="120"/>
        <source>The given MAC/machine is invalid.</source>
        <translation>Le couple machine/MAC donné est incorrect.</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="120"/>
        <source>Reason :</source>
        <translation>Raison :</translation>
    </message>
    <message>
        <source>The given MAC/machine is invalid.
Reason :</source>
        <translation type="obsolete">Le couple machine/MAC donné est invalide.\nRaison :</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <source>MAC Filter...</source>
        <translation>Filtrage MAC...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="24"/>
        <source>MAC filtering is designed for Wifi mode only.</source>
        <translation>Le filtrage MAC n&apos;est actif que pour le Wifi.</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="37"/>
        <source>Enable all</source>
        <translation>Activer tout</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="44"/>
        <source>Disable all</source>
        <translation>Désactiver tout</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="117"/>
        <source>Add...</source>
        <translation>Ajouter...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="124"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="131"/>
        <source>Reset</source>
        <translation>Défaut</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation type="obsolete">WEP</translation>
    </message>
    <message>
        <source>USB</source>
        <translation type="obsolete">USB</translation>
    </message>
    <message>
        <source>Wifi</source>
        <translation type="obsolete">Wifi</translation>
    </message>
</context>
</TS>

==> qtmobilehotspot_0.3.2.tar.gz: qtmobilehotspot-0.3.2/qtmhMacFilter/libqtmhmacfilter-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>MacInputDialogClass</name>
    <message>
        <location filename="src/macinputdialog.ui" line="14"/>
        <location filename="src/ui_macinputdialog.h" line="96"/>
        <source>Add a new MAC...</source>
        <translation>Ajouter une nouvelle MAC...</translation>
    </message>
    <message>
        <location filename="src/macinputdialog.ui" line="24"/>
        <location filename="src/ui_macinputdialog.h" line="97"/>
        <source>Machine name :</source>
        <translation>Nom de machine</translation>
    </message>
    <message>
        <location filename="src/macinputdialog.ui" line="34"/>
        <location filename="src/ui_macinputdialog.h" line="98"/>
        <source>MAC address :</source>
        <translation>Adresse MAC</translation>
    </message>
</context>
<context>
    <name>MobileHotspotConfiguration</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="32"/>
        <source>MAC Filter</source>
        <translation>Filtrage MAC</translation>
    </message>
</context>
<context>
    <name>PluginGUI</name>
    <message>
        <location filename="src/plugingui.cpp" line="23"/>
        <source>Allow those MACs</source>
        <translation>Autoriser</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="24"/>
        <source>Deny those MACs</source>
        <translation>Interdire</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="25"/>
        <source>No filtering</source>
        <translation>Pas de filtrage</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="107"/>
        <source>Empty name</source>
        <translation>Nom vide</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="110"/>
        <source>A MAC address comes in 6 parts separated by colons (:)</source>
        <oldsource>A MAC address comes in 6 parts separated by semicolons</oldsource>
        <translation>Une adresse MAC est formée de 6 parties séparées par des double points</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="114"/>
        <source>A part of a MAC has a length of 2</source>
        <translation>Une partie de MAC a une longueur de 2</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="118"/>
        <source>Digits in a MAC go from 0 to f</source>
        <translation>Les caractères formant une MAC vont de 0 à f</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="124"/>
        <source>Invalid MAC</source>
        <translation>MAC invalide</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="124"/>
        <source>The given MAC/machine is invalid.</source>
        <translation>Le couple machine/MAC donné est incorrect.</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="124"/>
        <source>Reason :</source>
        <translation>Raison :</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="169"/>
        <location filename="src/plugingui.cpp" line="219"/>
        <source>Select a file...</source>
        <translation>Choisissez un fichier...</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="174"/>
        <location filename="src/plugingui.cpp" line="212"/>
        <location filename="src/plugingui.cpp" line="224"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="174"/>
        <location filename="src/plugingui.cpp" line="224"/>
        <source>Cannot open the selected file</source>
        <translation>Impossible d&apos;ouvrir le fichier choisi</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="198"/>
        <location filename="src/plugingui.cpp" line="203"/>
        <source>Invalid file content</source>
        <translation>Contenu de fichier invalide</translation>
    </message>
    <message>
        <source>The given MAC/machine is invalid.
Reason :</source>
        <translation type="obsolete">Le couple machine/MAC donné est invalide.\nRaison :</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <location filename="src/ui_plugingui.h" line="199"/>
        <source>MAC Filter...</source>
        <translation>Filtrage MAC...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="24"/>
        <location filename="src/ui_plugingui.h" line="200"/>
        <source>MAC filtering is designed for Wifi mode only.</source>
        <translation>Le filtrage MAC n&apos;est actif que pour le Wifi.</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="37"/>
        <location filename="src/ui_plugingui.h" line="201"/>
        <source>Load...</source>
        <translation>Charger...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="44"/>
        <location filename="src/ui_plugingui.h" line="202"/>
        <source>Save...</source>
        <translation>Sauver...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="51"/>
        <location filename="src/ui_plugingui.h" line="203"/>
        <source>Enable all</source>
        <translation>Activer tout</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="58"/>
        <location filename="src/ui_plugingui.h" line="204"/>
        <source>Disable all</source>
        <translation>Désactiver tout</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="131"/>
        <location filename="src/ui_plugingui.h" line="205"/>
        <source>Add...</source>
        <translation>Ajouter...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="138"/>
        <location filename="src/ui_plugingui.h" line="206"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="145"/>
        <location filename="src/ui_plugingui.h" line="207"/>
        <source>Reset</source>
        <translation>Défaut</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation type="obsolete">WEP</translation>
    </message>
    <message>
        <source>USB</source>
        <translation type="obsolete">USB</translation>
    </message>
    <message>
        <source>Wifi</source>
        <translation type="obsolete">Wifi</translation>
    </message>
</context>
</TS>
